@@ -40,6 +40,7 @@ struct _PtyxisProfileEditor
 
   AdwEntryRow       *label;
   AdwSwitchRow      *bold_is_bright;
+  AdwSpinRow        *cell_height_scale;
   AdwComboRow       *containers;
   AdwSwitchRow      *use_custom_commmand;
   AdwSwitchRow      *login_shell;
@@ -77,6 +78,23 @@ G_DEFINE_FINAL_TYPE (PtyxisProfileEditor, ptyxis_profile_editor, ADW_TYPE_NAVIGA
 
 static GParamSpec *properties[N_PROPS];
 
+static gboolean
+ptyxis_profile_editor_spin_row_show_decimal_cb (PtyxisProfileEditor *self,
+                                                AdwSpinRow          *spin)
+{
+  g_autofree char *text = NULL;
+  double value;
+
+  g_assert (PTYXIS_IS_PROFILE_EDITOR (self));
+  g_assert (ADW_IS_SPIN_ROW (spin));
+
+  value = adw_spin_row_get_value (spin);
+  text = g_strdup_printf ("%.1f", value);
+  gtk_editable_set_text (GTK_EDITABLE (spin), text);
+
+  return TRUE;
+}
+
 static gboolean
 string_to_index (GValue   *value,
                  GVariant *variant,
@@ -270,6 +288,9 @@ ptyxis_profile_editor_constructed (GObject *object)
   g_object_bind_property (self->profile, "bold-is-bright",
                           self->bold_is_bright, "active",
                           G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
+  g_object_bind_property (self->profile, "cell-height-scale",
+                          self->cell_height_scale, "value",
+                          G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
   g_object_bind_property (self->profile, "login-shell",
                           self->login_shell, "active",
                           G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
@@ -445,6 +466,7 @@ ptyxis_profile_editor_class_init (PtyxisProfileEditorClass *klass)
 
   gtk_widget_class_bind_template_child (widget_class, PtyxisProfileEditor, backspace_binding);
   gtk_widget_class_bind_template_child (widget_class, PtyxisProfileEditor, bold_is_bright);
+  gtk_widget_class_bind_template_child (widget_class, PtyxisProfileEditor, cell_height_scale);
   gtk_widget_class_bind_template_child (widget_class, PtyxisProfileEditor, cjk_ambiguous_width);
   gtk_widget_class_bind_template_child (widget_class, PtyxisProfileEditor, cjk_ambiguous_widths);
   gtk_widget_class_bind_template_child (widget_class, PtyxisProfileEditor, containers);
@@ -472,6 +494,7 @@ ptyxis_profile_editor_class_init (PtyxisProfileEditorClass *klass)
   gtk_widget_class_bind_template_child (widget_class, PtyxisProfileEditor, uuid_row);
 
   gtk_widget_class_bind_template_callback (widget_class, get_container_title);
+  gtk_widget_class_bind_template_callback (widget_class, ptyxis_profile_editor_spin_row_show_decimal_cb);
 
   gtk_widget_class_install_action (widget_class, "uuid.copy", NULL, ptyxis_profile_editor_uuid_copy);
   gtk_widget_class_install_action (widget_class, "profile.delete", NULL, ptyxis_profile_editor_profile_delete);
