@@ -69,6 +69,7 @@ struct _PtyxisWindow
   GSignalGroup          *selected_page_signals;
   PtyxisWindowDressing  *dressing;
   GtkBox                *visual_bell;
+  GPropertyAction       *interface_style_action;
 
   guint                  visual_bell_source;
   guint                  focus_active_tab_source;
@@ -567,17 +568,10 @@ static AdwTabPage *
 ptyxis_window_tab_overview_create_tab_cb (PtyxisWindow   *self,
                                           AdwTabOverview *tab_overview)
 {
-  g_autoptr(PtyxisProfile) profile = NULL;
-  PtyxisTab *tab;
-
   g_assert (PTYXIS_IS_WINDOW (self));
   g_assert (ADW_IS_TAB_OVERVIEW (tab_overview));
 
-  profile = ptyxis_window_dup_profile_for_param (self, "default");
-  tab = ptyxis_tab_new (profile);
-
-  ptyxis_window_add_tab (self, tab);
-  ptyxis_window_set_active_tab (self, tab);
+  gtk_widget_activate_action (GTK_WIDGET (tab_overview), "win.new-tab", "(ss)", "", "");
 
   return adw_tab_view_get_selected_page (self->tab_view);
 }
@@ -1460,8 +1454,8 @@ ptyxis_window_add_theme_controls (PtyxisWindow *self)
   g_assert (PTYXIS_IS_WINDOW (self));
 
   settings = ptyxis_application_get_settings (PTYXIS_APPLICATION_DEFAULT);
-  interface_style = g_property_action_new ("interface-style", settings, "interface-style");
-  g_action_map_add_action (G_ACTION_MAP (self), G_ACTION (interface_style));
+  self->interface_style_action = g_property_action_new ("interface-style", settings, "interface-style");
+  g_action_map_add_action (G_ACTION_MAP (self), G_ACTION (self->interface_style_action));
 
   popover = gtk_menu_button_get_popover (self->primary_menu_button);
   selector = g_object_new (PTYXIS_TYPE_THEME_SELECTOR,
@@ -1654,6 +1648,8 @@ ptyxis_window_dispose (GObject *object)
 
   self->disposed = TRUE;
 
+  g_action_map_remove_action (G_ACTION_MAP (self), "interface-style");
+
   gtk_widget_dispose_template (GTK_WIDGET (self), PTYXIS_TYPE_WINDOW);
 
   g_signal_group_set_target (self->active_tab_signals, NULL);
@@ -1662,6 +1658,7 @@ ptyxis_window_dispose (GObject *object)
   g_signal_group_set_target (self->selected_page_signals, NULL);
   g_clear_handle_id (&self->focus_active_tab_source, g_source_remove);
   g_clear_object (&self->parking_lot);
+  g_clear_object (&self->interface_style_action);
 
   G_OBJECT_CLASS (ptyxis_window_parent_class)->dispose (object);
 }
